@@ -85,6 +85,10 @@ def ask_user_questions():
 
 	global_menu.enable('packages')
 
+	if archinstall.arguments.get('advanced', False):
+		# Enable parallel downloads
+		global_menu.enable('parallel downloads')
+
 	# Ask or Call the helper function that asks the user to optionally configure a network.
 	global_menu.enable('nic')
 
@@ -181,17 +185,22 @@ def perform_installation(mountpoint):
 			archinstall.use_mirrors(archinstall.arguments['mirror-region'])  # Set the mirrors for the live medium
 
 		# Retrieve list of additional repositories and set boolean values appropriately
-		enable_testing = 'testing' in archinstall.arguments.get('additional-repositories', None)
-		enable_multilib = 'multilib' in archinstall.arguments.get('additional-repositories', None)
+		if archinstall.arguments.get('additional-repositories', None) is not None:
+			enable_testing = 'testing' in archinstall.arguments.get('additional-repositories', None)
+			enable_multilib = 'multilib' in archinstall.arguments.get('additional-repositories', None)
+		else:
+			enable_testing = False
+			enable_multilib = False
 
 		if installation.minimal_installation(testing=enable_testing, multilib=enable_multilib):
 			installation.set_locale(archinstall.arguments['sys-language'], archinstall.arguments['sys-encoding'].upper())
 			installation.set_hostname(archinstall.arguments['hostname'])
-			if archinstall.arguments['mirror-region'].get("mirrors", None) is not None:
-				installation.set_mirrors(archinstall.arguments['mirror-region'])  # Set the mirrors in the installation medium
-			if archinstall.arguments['swap']:
+			if archinstall.arguments.get('mirror-region') is not None:
+				if archinstall.arguments.get("mirrors", None) is not None:
+					installation.set_mirrors(archinstall.arguments['mirror-region'])  # Set the mirrors in the installation medium
+			if archinstall.arguments.get('swap'):
 				installation.setup_swap('zram')
-			if archinstall.arguments["bootloader"] == "grub-install" and archinstall.has_uefi():
+			if archinstall.arguments.get("bootloader") == "grub-install" and archinstall.has_uefi():
 				installation.add_additional_packages("grub")
 			installation.add_bootloader(archinstall.arguments["bootloader"])
 
@@ -259,7 +268,7 @@ def perform_installation(mountpoint):
 		if not archinstall.arguments.get('silent'):
 			prompt = str(_('Would you like to chroot into the newly created installation and perform post-installation configuration?'))
 			choice = Menu(prompt, Menu.yes_no(), default_option=Menu.yes()).run()
-			if choice == Menu.yes():
+			if choice.value == Menu.yes():
 				try:
 					installation.drop_to_shell()
 				except:
@@ -274,7 +283,7 @@ if not (archinstall.check_mirror_reachable() or archinstall.arguments.get('skip-
 	archinstall.log(f"Arch Linux mirrors are not reachable. Please check your internet connection and the log file '{log_file}'.", level=logging.INFO, fg="red")
 	exit(1)
 
-if not archinstall.arguments.get('offline', False):
+if not archinstall.arguments.get('offline'):
 	latest_version_archlinux_keyring = max([k.pkg_version for k in archinstall.find_package('archlinux-keyring')])
 
 	# If we want to check for keyring updates
