@@ -1,4 +1,7 @@
-from typing import Optional
+from typing import Optional, TYPE_CHECKING
+
+if TYPE_CHECKING:
+	from .general import SysCommandWorker
 
 class RequirementError(BaseException):
 	pass
@@ -17,10 +20,11 @@ class ProfileError(BaseException):
 
 
 class SysCallError(BaseException):
-	def __init__(self, message :str, exit_code :Optional[int] = None) -> None:
+	def __init__(self, message :str, exit_code :Optional[int] = None, worker :Optional['SysCommandWorker'] = None) -> None:
 		super(SysCallError, self).__init__(message)
 		self.message = message
 		self.exit_code = exit_code
+		self.worker = worker
 
 
 class PermissionError(BaseException):
