@@ -7,6 +7,6 @@ from .network_conf import ask_to_configure_network
 from .partitioning_conf import select_partition, select_encrypted_partitions
 from .general_conf import (ask_ntp, ask_for_a_timezone, ask_for_audio_selection, select_language, select_mirror_regions,
 							select_profile, select_archinstall_language, ask_additional_packages_to_install,
-							select_additional_repositories, ask_hostname)
+							select_additional_repositories, ask_hostname, add_number_of_parrallel_downloads)
 from .disk_conf import ask_for_main_filesystem_format, select_individual_blockdevice_usage, select_disk_layout, select_disk
 from .utils import get_password, do_countdown
